/**************************************
  Auto hide main window
  (c) 1999 Daniel Serodio
  GnomeICU
***************************************/

/*** GnomeICU header files ***/
#include "common.h"

void start_autohide_timeout_cb( GtkWidget *widget )
{
#ifdef TRACE_FUNCTION
	g_print( "start_autohide_timeout_cb\n" );
#endif

	/* if it isn't already running */
	if ( !autohide_timeout_tag && GTK_WIDGET_VISIBLE( widget ) )
	{
		autohide_timeout_tag = gtk_timeout_add( autohide_time * 1000,
							(GtkFunction) applet_hide_main, GINT_TO_POINTER(1));
	}
}

void stop_autohide_timeout_cb( GtkWidget *widget )
{
#ifdef TRACE_FUNCTION
	g_print( "stop_autohide_timeout_cb\n" );
#endif

	if (autohide_timeout_tag)
	{
		gtk_timeout_remove( autohide_timeout_tag );
		/* so we know it's not running anymore */
		autohide_timeout_tag = 0;
	}
}
